﻿#################################################################################
#                                                                               #
#                       copyright (c) 2003 Ingeniweb SARL                       #
#                                                                               #
#################################################################################

"""PloneSearchBoxTool main class"""

from string import find, split, lstrip
from Products.CMFCore.utils import UniqueObject, _getAuthenticatedUser, _checkPermission
from Products.CMFCore.utils import getToolByName, _dtmldir
from OFS.SimpleItem import SimpleItem
from OFS import ObjectManager
from Globals import InitializeClass, DTMLFile, MessageDialog, ImageFile, \
     PersistentMapping
from Acquisition import aq_base
from AccessControl.User import nobody
from AccessControl import ClassSecurityInfo
from Products.CMFCore.CMFCorePermissions import *
from Products.CMFCore.ActionProviderBase import ActionProviderBase
from Products.PageTemplates.PageTemplateFile import PageTemplateFile

from global_symbols import *

import sys
import string

class PloneSearchBoxTool(UniqueObject, ObjectManager.ObjectManager, SimpleItem, ActionProviderBase):
    """
    PloneSearchBoxTool tool
    """
    id = 'portal_searchbox'
    meta_type = 'PloneSearchBox Tool'
    _actions = []
    security = ClassSecurityInfo()

    manage_options = (
        (         
         {'label' : 'Configuration',
          'action' : 'manage_configure',
         },
         {'label' : 'Sources permissions',
          'action' : 'manage_sourcesSecurityForm',
         },
         ) +
        ActionProviderBase.manage_options +
        SimpleItem.manage_options
        )
    #security.declareProtected(ManagePortal, 'manage_overview' )
    #manage_overview = DTMLFile('skins/PloneSearchBox/plonesearchbox_overview', globals())

    security.declareProtected(CMFCorePermissions.ManagePortal,
                              'manage_configure')    
    manage_configure = PageTemplateFile(
                        'www/plonesearchboxtool_configure',
                        globals(),
                        __name__='manage_configure')

    
     #############################################################################
    #                                                                           #
    #                             SEARCHBOX TOOL PROPERTIES                     #
    #                                                                           #
    #############################################################################
    
    _searchEngines = [
            ('#Some example of search engines', ''),
            ('Google FR', 'http://google.fr/search?q=%(text)s'),
            ('#Voila FR', 'http://search.ke.voila.fr/S/voila?dt=*&kw=%(text)s'),
            ('#Altavista FR', 'http://fr.altavista.com/web/results?q=%(text)s&kgs=1&kls=1&avkw=aapt'),
            ('#Yahoo FR', 'http://fr.search.yahoo.com/search/fr?fr=fp-top&p=%(text)s&y=y'),
            ('Plone', 'http://plone.org/search?SearchableText=%(text)s'),
            ('Zopera', 'http://zopera.org/search?SearchableText=%(text)s'),
            ('#Google EN', 'http://google.com/search?q=%(text)s'),
            ('#Traduire FR/EN', 'http://translate.google.com/translate_t?langpair=fr|en&ie=acii&oe=ascii&text=%(text)s'),
            ('Conjuguer', 'http://www.leconjugueur.com/php/frconjugue.php?verbe=%(verbe ?onjuguer)s'),
            ('Pages Jaunes',
             'http://pagesjaunes.fr/pj.cgi?faire=decode_input_image&DEFAULT_ACTION=jf_inscriptions_req&lang=FR&pays=FR&srv=PJ&TYPE_RECHERCHE=CLOC&input_image=&FRM_ACTIVITE=%(Activit?&FRM_NOM=%(Nom)s&FRM_ADRESSE=%(Adresse)s&FRM_LOCALITE=%(Localit?&FRM_DEPARTEMENT=%(D?rtement)s&JF_INSCRIPTIONS_REQ.x=55&JF_INSCRIPTIONS_REQ.y=14'),
            ('#Traduction/D?nition', 'http://webster.com/cgi-bin/dictionary?book=Dictionary&va=%(text)s'),
            ('#Pages Blanches','http://www.pagesjaunes.fr/pb.cgi?faire=decode_input_image&DEFAULT_ACTION=bf_inscriptions_req&lang=FR&pays=FR&srv=PB&TYPE_RECHERCHE=ZZZ&input_image=&FRM_NOM=%(Nom)s&FRM_PRENOM=%(Pr?m)s&FRM_ADRESSE=%(Adresse)s&FRM_LOCALITE=%(Localit?&FRM_DEPARTEMENT=%(D?rtement)s&BF_INSCRIPTIONS_REQ.x=54&BF_INSCRIPTIONS_REQ.y=12'),
            ('#Trajet','http://1bis.com/1bis/way/way.asp?x1=&x2=&y1=&y2=&cityId1=&streetId1=&cityId2=&streetId2=&city1=%(Ville de d?rt)s&street1=%(Rue de d?rt)s&number1=%(N)s&city2=%(Ville d\'arriv?s&street2=%(Rue d\'arriv?s&number2=%(N)s&x=14&y=4'),
            ('#Societe', 'http://societe.com/cgi-bin/liste?nom=%(Entreprise)s&dirig=%(Dirigeant)s&pre=%(Pr?m)s&ape=%(Code APE)s&dep=%(D?rtement)s&image2.x=55&image2.y=9'),
            ('FreshMeat', 'http://freshmeat.net/search/?q=%(projet)s&section=projects&x=13&y=13'),
            ('#Synonymes','http://elsap1.unicaen.fr/cgi-bin/trouvebis?requete=%(text)s&refer=#classement')
    ]
    _currentRubricSearch = 1
    _portalSearch = 1
    _resultInWindow = 0
    _portalRubricSearch = 0
    
    #############################################################################
    #                                                                           #
    #                             SEARCHBOX TOOL METHODS                        #
    #                                                                           #
    #############################################################################

    security.declareProtected(CMFCorePermissions.ManagePortal,
                              'manage_addEngines')
    def  manage_addEngines(self, engines, REQUEST=None, cbPortalSearch=None,
                           cbCurrentRubricSearch=None, cbResultInWindow=None, cbPortalRubricSearch=None):
        """ Change the configuration of the PloneSearchBox tool """
        self.setListEngines(engines)
        if cbPortalSearch:
            self._portalSearch = 1
        else:
            self._portalSearch = 0
        if cbCurrentRubricSearch:
            self._currentRubricSearch = 1
        else:
            self._currentRubricSearch = 0
        if cbResultInWindow:
            self._resultInWindow = 1
        else:
            self._resultInWindow = 0
        if cbPortalRubricSearch:
            self._portalRubricSearch = 1
        else:
            self._portalRubricSearch = 0
        if REQUEST is not None:  
            return self.manage_configure(self, REQUEST,
                         manage_tabs_message="Saved.")
            
    security.declarePublic('getPortalSearch')
    def getPortalSearch(self,):
        """ Return _portalSearch property of the PloneSearchBox Tool """
        return self._portalSearch

    security.declarePublic('getCurrentRubricSearch')
    def getCurrentRubricSearch(self,):
        """ Return _currentRubricSearch property of the PloneSearchBox Tool """
        return self._currentRubricSearch
    
    security.declarePublic('getPortalRubricSearch')
    def getPortalRubricSearch(self,):
        """ Return _listPortalRubric property of the PloneSearchBox Tool """
        return self._portalRubricSearch
    
    security.declareProtected(CMFCorePermissions.ManagePortal, 'list2text')
    def list2text(self,):
        """Return the object list of tuple in a simple text with line breaks"""
        text = ""
        aList = self._searchEngines
        for element in aList:
            if len(element) > 1:
               text = text + element[0] + ';' + element[1] + '\r\n'
        return text
       
    security.declarePublic('getListEngines')
    def getListEngines(self,):
        """
        Return _searchEnginesList property of the PloneSearchBox Tool
        without commented lines (#)
        """
        commentChar = '#'
        searchEnginesList = []
        for engine, url in self._searchEngines:
            firstChar = engine[0][0]
            if not firstChar == commentChar:
                searchEnginesList.append((engine, url))
        return searchEnginesList

    security.declarePrivate('setListEngines')
    def setListEngines(self, engines):
        """
        Transform lines into a list of tuple. The line is split
        from separator ';', if first char is '#' it will be a comment
        """
        commentChar = '#'
        self._searchEngines = []
        if engines:
            engines = engines.splitlines()
            for line in engines:
                element = line.split(";")
                if len(element) > 1:
                    engine = (element[0], element[1])
                    if commentChar in element[0]:
                        engine = (element[0], '')
                    self._searchEngines.append(engine)
    
    security.declarePublic('isResultInWindow')
    def isResultInWindow(self,):
        """ Return _resultInWindow property of the PloneSearchBox Tool"""
        return self._resultInWindow
    
    security.declarePublic('getPortalRubrics')
    def getPortalRubrics(self,):
        portalRubrics = []
        root = self.portal_url.getPortalObject() # Site Root
        rootFolders = root.objectValues('Plone Folder')
        for object in rootFolders:
            try:
                x = object.objectValues() # should raise if folder is Private
                user = self.portal_membership.getAuthenticatedMember()
                if object.isPrincipiaFolderish and user.has_permission('View', object):
                    rubric = (object.title, string.join(object.getPhysicalPath(), '/'))
                    portalRubrics.append(rubric)
            except:
                pass
        return portalRubrics
    
InitializeClass(PloneSearchBoxTool)